package main

import (
	"io"
	"net/http"

	"github.com/andybalholm/cascadia"
	"github.com/yuin/gopher-lua"
	"golang.org/x/net/html"
)

func cssfilter(css string) cascadia.Selector {
	return cascadia.MustCompile(css)
}

func matchfirst(node *html.Node, sel cascadia.Selector) *html.Node {
	return sel.MatchFirst(node)
}

func matchall(node *html.Node, sel cascadia.Selector) []*html.Node {
	return sel.MatchAll(node)
}

func removenode(node *html.Node) {
	node.Parent.RemoveChild(node)
}

func writestring(w io.Writer, s string) {
	w.Write([]byte(s))
}

func reqgethost(req *http.Request) string {
	return req.URL.Host
}

func reqsethost(req *http.Request, host string) {
	req.URL.Host = host
}

func addfunctions(L *lua.LState) {
	L.SetGlobal("cssfilter", L.NewFunction(func2lua(cssfilter)))
	L.SetGlobal("matchfirst", L.NewFunction(func2lua(matchfirst)))
	L.SetGlobal("matchall", L.NewFunction(func2lua(matchall)))
	L.SetGlobal("removenode", L.NewFunction(func2lua(removenode)))
	L.SetGlobal("clean", L.NewFunction(func2lua(clean)))
	L.SetGlobal("writestring", L.NewFunction(func2lua(writestring)))
	L.SetGlobal("reqgethost", L.NewFunction(func2lua(reqgethost)))
	L.SetGlobal("reqsethost", L.NewFunction(func2lua(reqsethost)))
}
